@@ -9,7 +9,7 @@ from labstep.entities.experimentStep.model import ExperimentStep
 from labstep.entities.experimentTable.model import ExperimentTable
 from labstep.entities.experimentTimer.model import ExperimentTimer
 import labstep.entities.file.repository as fileRepository
-import labstep.entities.experimentMaterial.repository as experimentMaterialRepository
+import labstep.entities.experimentInventoryField.repository as experimentInventoryFieldRepository
 from labstep.constants import UNSPECIFIED
 
 
@@ -84,14 +84,14 @@ class ExperimentProtocol(Entity):
         self.update()
         return getattr(self, "state", None)
 
-    def getMaterials(self, count=100, extraParams={}):
+    def getInventoryFields(self, count=100, extraParams={}):
         """
-        Returns a list of the materials in a Protocol within an Experiment.
+        Returns a list of the inventory fields in a Protocol within an Experiment.
 
         Returns
         -------
-        List[:class:`~labstep.entities.experimentMaterial.model.ExperimentMaterial`]
-            List of the materials in an Experiment's Protocol.
+        List[:class:`~labstep.entities.experimentInventoryField.model.ExperimentInventoryField`]
+            List of the inventory fields in an Experiment's Protocol.
 
         Example
         -------
@@ -99,14 +99,14 @@ class ExperimentProtocol(Entity):
 
             experiment = user.getExperiment(17000)
             exp_protocol = experiment.getProtocols()[0]
-            exp_protocol_materials = exp_protocol.getMaterials()
-            exp_protocol_materials[0].attributes()
+            exp_protocol_inventory_fields = exp_protocol.getInventoryFields()
+            exp_protocol_inventory_fields[0].attributes()
         """
 
-        return experimentMaterialRepository.getExperimentMaterials(self.__user__,
-                                                                   experiment_id=self.id, count=count, extraParams=extraParams)
+        return experimentInventoryFieldRepository.getExperimentInventoryFields(self.__user__,
+                                                                               experiment_id=self.id, count=count, extraParams=extraParams)
 
-    def addMaterial(
+    def addInventoryField(
         self,
         name=UNSPECIFIED,
         amount=UNSPECIFIED,
@@ -116,12 +116,12 @@ class ExperimentProtocol(Entity):
         extraParams={},
     ):
         """
-        Add a new material to the ExperimentProtocol.
+        Add a new inventory field to the ExperimentProtocol.
 
         Parameters
         ----------
         name (str)
-            The name of the material to add.
+            The name of the inventory field to add.
         amount (str)
             The amount used.
         units (str)
@@ -134,8 +134,8 @@ class ExperimentProtocol(Entity):
 
         Returns
         -------
-        :class:`~labstep.entities.experimentMaterial.model.ExperimentMaterial`
-            The newly added material entity.
+        :class:`~labstep.entities.experimentInventoryField.model.ExperimentInventoryField`
+            The newly added inventory field entity.
 
         Example
         -------
@@ -143,17 +143,17 @@ class ExperimentProtocol(Entity):
 
             experiment = user.getExperiment(17000)
             resource = user.getResources(search_query='Sample A')[0]
-            experiment.addMaterial(name='Sample A', amount='2', units='ml',
+            experiment.addInventoryField(name='Sample A', amount='2', units='ml',
                                  resource_id=resource.id)
         """
-        return experimentMaterialRepository.newExperimentMaterial(self.__user__,
-                                                                  experiment_id=self.id,
-                                                                  name=name,
-                                                                  amount=amount,
-                                                                  units=units,
-                                                                  resource_id=resource_id,
-                                                                  resource_item_id=resource_item_id,
-                                                                  extraParams=extraParams)
+        return experimentInventoryFieldRepository.newExperimentInventoryField(self.__user__,
+                                                                              experiment_id=self.id,
+                                                                              name=name,
+                                                                              amount=amount,
+                                                                              units=units,
+                                                                              resource_id=resource_id,
+                                                                              resource_item_id=resource_item_id,
+                                                                              extraParams=extraParams)
 
     def addSteps(self, N):
         """
@@ -243,7 +243,10 @@ class ExperimentProtocol(Entity):
             exp_protocol_steps[0].attributes()
         """
         self.update()
-        steps = self.experiment_steps
+        if hasattr(self, 'experiment_steps'):
+            steps = self.experiment_steps
+        else:
+            steps = self.protocol_steps
         return EntityList(steps, ExperimentStep, self.__user__)
 
     def addTimer(self, name=UNSPECIFIED, hours=UNSPECIFIED, minutes=UNSPECIFIED, seconds=UNSPECIFIED):
@@ -304,7 +307,10 @@ class ExperimentProtocol(Entity):
             exp_protocol_tables[0].attributes()
         """
         self.update()
-        tables = self.experiment_tables
+        if hasattr(self, 'experiment_tables'):
+            tables = self.experiment_tables
+        else:
+            tables = self.protocol_tables
         return EntityList(tables, ExperimentTable, self.__user__)
 
     def getTimers(self):
@@ -326,7 +332,10 @@ class ExperimentProtocol(Entity):
             exp_protocol_timers[0].attributes()
         """
         self.update()
-        timers = self.experiment_timers
+        if hasattr(self, 'experiment_timers'):
+            timers = self.experiment_timers
+        else:
+            timers = self.protocol_timers
         return EntityList(timers, ExperimentTimer, self.__user__)
 
     def getDataFields(self):
@@ -467,10 +476,16 @@ class ExperimentProtocol(Entity):
 
     @deprecated(version='3.3.2', reason="You should use experimentProtocol.addDataField instead")
     def addDataElement(self, *args, **kwargs):
-
         return self.addDataField(*args, **kwargs)
 
     @deprecated(version='3.3.2', reason="You should use experimentProtocol.getDataFields instead")
     def getDataElements(self):
-
         return self.getDataFields()
+
+    @deprecated(version='3.12.0', reason="You should use getInventoryFields instead")
+    def getMaterials(self, *args, **kwargs):
+        return self.getInventoryFields(*args, **kwargs)
+
+    @deprecated(version='3.12.0', reason="You should use addInventoryField instead")
+    def addMaterial(self, *args, **kwargs):
+        return self.addInventoryField(*args, **kwargs)
