@@ -12,12 +12,12 @@ def exportExperimentProtocol(experimentProtocol, rootPath, folderName):
     expDir = entityRepository.exportEntity(
         experimentProtocol, rootPath, folderName=folderName)
 
-    # save materials
-    materialsDir = expDir.joinpath('materials')
-    materials = experimentProtocol.getMaterials()
+    # save inventory fields
+    inventoryFieldsDir = expDir.joinpath('inventory')
+    inventoryFields = experimentProtocol.getInventoryFields()
 
-    for material in materials:
-        material.export(materialsDir)
+    for inventoryField in inventoryFields:
+        inventoryField.export(inventoryFieldsDir)
 
     # save data
     dataDir = expDir.joinpath('data')
