@@ -6,6 +6,7 @@ from labstep.service.helpers import getTime
 from labstep.generic.entityPrimary.model import EntityPrimary
 from labstep.generic.entityWithMetadata.model import EntityWithMetadata
 from labstep.entities.resourceItem.model import ResourceItem
+from labstep.constants import UNSPECIFIED
 
 
 class Resource(EntityPrimary, EntityWithMetadata):
@@ -24,7 +25,7 @@ class Resource(EntityPrimary, EntityWithMetadata):
 
     __entityName__ = "resource"
 
-    def edit(self, name=None, extraParams={}):
+    def edit(self, name=UNSPECIFIED, extraParams={}):
         """
         Edit an existing Resource.
 
@@ -151,7 +152,7 @@ class Resource(EntityPrimary, EntityWithMetadata):
             extraParams=extraParams,
         )
 
-    def getItems(self, count=100, search_query=None, extraParams={}):
+    def getItems(self, count=100, search_query=UNSPECIFIED, extraParams={}):
         """
         Returns the items of this Resource.
 
@@ -188,11 +189,11 @@ class Resource(EntityPrimary, EntityWithMetadata):
 
     def newItem(
         self,
-        name=None,
+        name=UNSPECIFIED,
         availability="available",
-        quantity_amount=None,
-        quantity_unit=None,
-        resource_location_id=None,
+        quantity_amount=UNSPECIFIED,
+        quantity_unit=UNSPECIFIED,
+        resource_location_id=UNSPECIFIED,
         extraParams={},
     ):
         """
